@@ -1,6 +1,6 @@
 /*
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2013 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2014 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -509,13 +509,13 @@ free_dhcp_opt_embenc(struct dhcp_opt *opt)
 	free(opt->var);
 
 	for (i = 0, o = opt->embopts; i < opt->embopts_len; i++, o++)
-		free(o->var);
+		free_dhcp_opt_embenc(o);
 	free(opt->embopts);
 	opt->embopts_len = 0;
 	opt->embopts = NULL;
 
 	for (i = 0, o = opt->encopts; i < opt->encopts_len; i++, o++)
-		free(o->var);
+		free_dhcp_opt_embenc(o);
 	free(opt->encopts);
 	opt->encopts_len = 0;
 	opt->encopts = NULL;
@@ -525,6 +525,8 @@ static char *
 strwhite(const char *s)
 {
 
+	if (s == NULL)
+		return NULL;
 	while (*s != ' ' && *s != '\t') {
 		if (*s == '\0')
 			return NULL;
@@ -537,6 +539,8 @@ static char *
 strskipwhite(const char *s)
 {
 
+	if (s == NULL)
+		return NULL;
 	while (*s == ' ' || *s == '\t') {
 		if (*s == '\0')
 			return NULL;
@@ -1053,10 +1057,7 @@ parse_option(struct if_options *ifo, int opt, const char *arg)
 			}
 			ifo->arping = naddr;
 			ifo->arping[ifo->arping_len++] = addr.s_addr;
-			if (fp)
-				arg = strskipwhite(fp);
-			else
-				arg = NULL;
+			arg = strskipwhite(fp);
 		}
 		break;
 	case O_DESTINATION:
@@ -1083,6 +1084,7 @@ parse_option(struct if_options *ifo, int opt, const char *arg)
 		if (parse_iaid(ifo->iaid, arg, sizeof(ifo->iaid)) == -1)
 			return -1;
 		ifo->options |= DHCPCD_IAID;
+		break;
 	case O_IPV6RS:
 		ifo->options |= DHCPCD_IPV6RS;
 		break;
@@ -1282,7 +1284,7 @@ parse_option(struct if_options *ifo, int opt, const char *arg)
 			u = 0;
 		else {
 			fp = strwhite(arg);
-			if (!fp) {
+			if (fp == NULL) {
 				syslog(LOG_ERR, "invalid syntax: %s", arg);
 				return -1;
 			}
@@ -1294,6 +1296,10 @@ parse_option(struct if_options *ifo, int opt, const char *arg)
 				return -1;
 			}
 			arg = strskipwhite(fp);
+			if (arg == NULL) {
+				syslog(LOG_ERR, "invalid syntax");
+				return -1;
+			}
 		}
 		/* type */
 		fp = strwhite(arg);
@@ -1548,10 +1554,11 @@ read_config(const char *file,
 	int skip = 0, have_profile = 0;
 #ifndef EMBEDDED_CONFIG
 	char *buf;
-	const char **e;
+	const char * const *e;
 	size_t buflen, ol;
 #endif
 #if !defined(INET) || !defined(INET6)
+	size_t i;
 	struct dhcp_opt *opt;
 #endif
 
@@ -1669,7 +1676,7 @@ read_config(const char *file,
 		dhcp6_opts_len = ifo->dhcp6_override_len;
 #else
 		for (i = 0, opt = ifo->dhcp6_override;
-		    i < ifo->dhcp_override6_len;
+		    i < ifo->dhcp6_override_len;
 		    i++, opt++)
 			free_dhcp_opt_embenc(opt);
 		free(ifo->dhcp6_override);
